==> lib-js-vuex-access-gate-1.1.8.tgz: package/src/gate/actions.js <==

export default { 
  unlockGates(context, route) {
    const gates = context.state.gates;
    const bypass = route && context.state.bypassRoutes.length && context.state.bypassRoutes.indexOf(route) > -1;
    let unlocked = true;
    if(!bypass) {
      for (let i = 0; i < gates.length; i++) {
        let keepOut = gates[i].tryLock(context);
        unlocked = (keepOut)? false : unlocked;
        context.commit('setLock',{index: i, locked: keepOut});
      }
    }
    if(unlocked) {
        context.commit('openGate');
    } else {
        context.commit('closeGate');
    }
  },
  getIPCity({
        commit,
        rootState
    }) {

        let site = rootState.ecosystem? rootState : rootState.site || rootState.default

        let cityEndpoint = site.ecosystem['locations-api'].base_url  + '/api/v1/ips';      
        let findIP = new Promise( r => { 
        var w = window, 
        a = new (w.RTCPeerConnection||w.mozRTCPeerConnection||w.webkitRTCPeerConnection)({ iceServers: [] }),
        b = () => {};
        a.createDataChannel('');
        a.createOffer( c => a.setLocalDescription(c, b, b), b);
        a.onicecandidate = c => {
                try {
                    c.candidate.candidate.match(/([0-9]{1,3}(\.[0-9]{1,3}){3}|[a-f0-9]{1,4}(:[a-f0-9]{1,4}){7})/g).forEach(ip => {
                    let params = { ip }
                    axios.get(cityEndpoint, { params })
                        .then((response) => {
                            let result = response.data;
                            if(!result.error) {
                                commit('setIPCity', result);
                                r(result);
                            }
                    });
                  })
                }
                catch(e) {
                   // surpress error
                }
            }
        })
        return findIP
    }
}

==> lib-js-vuex-access-gate-1.1.9.tgz: package/src/gate/actions.js <==

export default { 
  unlockGates(context, route) {
    const gates = context.state.gates;
    const bypass = route && context.state.bypassRoutes.length && context.state.bypassRoutes.indexOf(route) > -1;
    let unlocked = true;
    if(!bypass) {
      for (let i = 0; i < gates.length; i++) {
        let keepOut = gates[i].tryLock(context);
        unlocked = (keepOut)? false : unlocked;
        context.commit('setLock',{index: i, locked: keepOut});
      }
    }
    if(unlocked) {
        context.commit('openGate');
    } else {
        context.commit('closeGate');
    }
  },
  getIPCity({
        commit,
        rootState
    }) {

        let site = rootState.ecosystem? rootState : rootState.default || rootState.site
 
        let cityEndpoint = site.ecosystem['locations-api'].base_url  + '/api/v1/ips';      
        let findIP = new Promise( r => { 
        var w = window, 
        a = new (w.RTCPeerConnection||w.mozRTCPeerConnection||w.webkitRTCPeerConnection)({ iceServers: [] }),
        b = () => {};
        a.createDataChannel('');
        a.createOffer( c => a.setLocalDescription(c, b, b), b);
        a.onicecandidate = c => {
                try {
                    c.candidate.candidate.match(/([0-9]{1,3}(\.[0-9]{1,3}){3}|[a-f0-9]{1,4}(:[a-f0-9]{1,4}){7})/g).forEach(ip => {
                    let params = { ip }
                    axios.get(cityEndpoint, { params })
                        .then((response) => {
                            let result = response.data;
                            if(!result.error) {
                                commit('setIPCity', result);
                                r(result);
                            }
                    });
                  })
                }
                catch(e) {
                   // surpress error
                }
            }
        })
        return findIP
    }
}
